#### Building instructions.
#
### Overview of rebuild options:
#
# --without userland		: Build without the userland-package (default: with it)
# --without modules		: Build without the kernel-module-package (default: with it)
# --define 'ksrc srcdir' 	: Build with kernel header files found in <srcdir> 
# --define 'kernel kernelver' 	: Build for kernel <kernelver> instead of the current. Might in some cases 
#                                  needed in addition to ksrc or to build for a different fedora-kernel.  
#
### Examples:
#
## To rebuild whole package for the running kernel:
#
# rpmbuild -ba THIS.SPEC --target "$(uname -m)"
# 
## To rebuild only userland-package: 
#
# rpmbuild -ba THIS.SPEC --without modules
#
## To rebuild only kernel modules against currently running fedora kernel 
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" 
#
## To rebuild only kernel modules against a kernel where /lib/modules/$(uname -r)/build points
##  to the build-sources (e.g. self compiled, fedora-kernel without kernel-devel package)
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" --define "ksrc /lib/modules/$(uname -r)/build" 
#
#### End of Building instructions.


%{?ksrc: 	%{!?kernel:    %{expand: %%define kernel %(cd "%{ksrc}" &> /dev/null && echo "$(cat Makefile 2>/dev/null && echo $'\n'kernelhelper-rel:$'\n'$'\t'@echo \$\(KERNELRELEASE\)$'\n')" 2>/dev/null | make -f - kernelhelper-rel 2>/dev/null || echo "custom" ) }}}
%{!?kernel:             %{expand: %%define kernel %(uname -r)}}
%define modpath   	drivers/net

Name:           r1000
Version:        2.2
Release:        1.SL4x
Epoch:          0
Summary:        Driver for some RealTek Ethernet controllers
Group:          Documentation
License:        RealTek
URL:            http://www.realtek.com.tw/

Source:         %{name}-%{version}.tgz

ExclusiveArch:  x86_64 %{ix86}
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root


%description
This is the Linux device driver released for RealTek Ethernet controllers, 
which are listed as following.
        1. RTL8169S/SB/SC (Gigabit Ethernet with PCI interface)
        2. RTL8168B (Gigabit Ethernet with PCI-Express interface)
        3. RTL8101E (Fast Ethernet with PCI-Express interface)


%package -n kernel-module-%{name}-%{kernel}
Summary:     Driver for some RealTek Ethernet controllers
Group:		 System Environment/Kernel

Provides:	 kernel-module-%{name} = %{epoch}:%{version}-%{release}
Requires(post):  modutils
Requires(postun):modutils
%if 0%{!?ksrc:1}
Requires:	 /boot/vmlinuz-%{kernel}
%endif
%if 0%{!?_without_modules:1}
%if 0%{!?ksrc:1}
BuildRequires:  kernel-devel = %{kernel}
%endif
%endif

%description  -n kernel-module-%{name}-%{kernel}
This Package contains the kernel modules required for 
some RealTek Ethernet controllers.  This package is
built for kernel %{kernel} (%{_target_cpu}).


%prep
if [[ "%{kernel}" = "custom" ]]
then
	(
	set +ex
	echo $'\n'$'\n'"Could not determine your kernel version. You should pass the correct one with"
	echo "the rpmbuild parameter '--define \"kernel <output of uname -r of target kernel>\"'"
	echo "But probably there is something wrong with the ksrc you provided. Therefore the"
	echo "build might fail, too."$'\n'$'\n'
	)
	sleep 10
fi
%setup -n %{name}-%{version}

%build
%if 0%{!?_without_modules:1}
export KERNEL_PATH="%{?ksrc:%{ksrc}}%{!?ksrc:%{_usrsrc}/kernels/%{kernel}-%{_target_cpu}}"
make modules KVER=%{kernel} KDIR=$KERNEL_PATH
%endif 	#!?_without_modules:1

%install
rm -rf $RPM_BUILD_ROOT

%if 0%{!?_without_modules:1}
mkdir -p %{buildroot}/lib/modules/%{kernel}/%{modpath}/
make install DEST=%{buildroot}/lib/modules/%{kernel}/%{modpath}/
%endif  #!?_without_modules:1

%if 0%{!?_without_userland:1}
mkdir -p %{buildroot}/%{_docdir}/%{name}-%{version}
cp -r README release_note.txt %{buildroot}/%{_docdir}/%{name}-%{version}
%endif  #!?_without_userland:1


%clean
#rm -rf $RPM_BUILD_ROOT


%post -n kernel-module-%{name}-%{kernel}
%if 0%{!?ksrc:1}
if [ -r /boot/System.map-%{kernel} ] ; then
  /sbin/depmod -e -F /boot/System.map-%{kernel} %{kernel} > /dev/null || :
fi
%else
if [ "$(uname -r)" = "%{kernel}" ] ; then
  /sbin/depmod -a >/dev/null || :
fi
%endif


%postun -n kernel-module-%{name}-%{kernel}
%if 0%{!?ksrc:1}
if [ -r /boot/System.map-%{kernel} ] ; then
  /sbin/depmod -e -F /boot/System.map-%{kernel} %{kernel} > /dev/null || :
fi
%else
if [ "$(uname -r)" = "%{kernel}" ] ; then
  /sbin/depmod -a >/dev/null || :
fi
%endif


%if 0%{!?_without_modules:1}
%files -n kernel-module-%{name}-%{kernel}
%defattr(744,root,root,-)
/lib/modules/%{kernel}/%{modpath}/*
%endif  #!?_without_modules:1

%if 0%{!?_without_userland:1}
%files
%defattr(-,root,root,-)
%doc %{_docdir}/%{name}-%{version}

%endif  #!?_without_userland:1


%changelog
* Mon Feb 13 2006 Troy Dawson <dawson@fnal.gov> - 2.2-1.SL4x
- Built the spec file for 2.2

